function [displace_x,displace_y]= find_disp(cr_corr);
% ******************************************************** 
% Function to find peak position
% with a subpixel accuracy in a region of with size 
% equals to n_matrix X n_matrix pixels 
% ********** Parameters **************
% cr_corr       = cross correlation map (same size of the image window)
% displace_x    = displacement in x direction
% displace_x    = displacement in y direction
%**************************************
%********** Parameters **************
warning off;
n_matrix=7; % ALWAYS ODD NUMBERS!!
% around the initial peak
n_pts=size(cr_corr);
if n_pts(1)<2*n_matrix
    n_matrix=n_matrix-2;
end
zero_displ_x=n_pts(1)/2+1;% center of the cross correlation
zero_displ_y=n_pts(2)/2+1;% center of the cross correlation
if exist('f_p')==0
    f_p=1;
end



% finding first the peak with the coarse resolution of the image
[a,b]=max(cr_corr);
[c,coarse_peak_y]=max(a); %line maxima
coarse_peak_x=b(coarse_peak_y); %column of maxima
lim=(n_matrix-1)/2;
corr_x=0;%correction to move the lim window if the peak is too close to nyquist
corr_y=0;%correction to move the lim window if the peak is too close to nyquist

if f_p==1   
    %If too close to alias, then reduce the size of the matrix used in the
    %adjust
    if (coarse_peak_x-lim)==0 & n_matrix>3
        %    coarse_peak_x=coarse_peak_x+1;
        n_matrix=n_matrix-2;
        %disp(['Warning - correlation x=0'])    %displace_x=0;
        %displace_y=0;
        lim=(n_matrix-1)/2;
    elseif (coarse_peak_x+lim)==(n_pts+1) & n_matrix>3
        %    coarse_peak_x=coarse_peak_x-1;
        n_matrix=n_matrix-2;
        %disp(['Warning - correlation x>'])
        lim=(n_matrix-1)/2;
    elseif (coarse_peak_x-lim)<0 | (coarse_peak_x+lim)>(n_pts+1)        
        disp(['Warning-bad correlation Nan x'])
        displace_x=nan;
        displace_y=nan;
        return
    end
    if (coarse_peak_y-lim)==0 & n_matrix>3
        %    coarse_peak_y=coarse_peak_y+1;
        n_matrix=n_matrix-2;
        %disp(['Warning - correlation y=0'])
        %displace_x=0;
        %displace_y=0;
        lim=(n_matrix-1)/2;
    elseif (coarse_peak_y+lim)==(n_pts+1) & n_matrix>3
        %    coarse_peak_y=coarse_peak_y-1;
        n_matrix=n_matrix-2;
        %disp(['Warning - correlation y>'])
        lim=(n_matrix-1)/2;
    elseif coarse_peak_y-lim<=0 | coarse_peak_y+lim>=n_pts+1
        disp(['Warning-bad correlation Nan y'])
        displace_x=nan;
        displace_y=nan;
        return
    end
    
    
    %disp(['coarse_x=' num2str(coarse_peak_x) , 'coarse_y=' num2str(coarse_peak_y) ])
    %disp(['n_pts' num2str(n_pts(1)) ', x-=' num2str(coarse_peak_x-lim) ', x+=' num2str(coarse_peak_x+lim) ', y-=' num2str(coarse_peak_y-lim) ', y+=' num2str(coarse_peak_y+lim)]);
    img_tmp(1:n_matrix,1:n_matrix)=cr_corr(coarse_peak_x-lim:coarse_peak_x+lim,coarse_peak_y-lim:coarse_peak_y+lim);
    
    %**********************************************************************
    %              Fit Options: Gaussian 2D, Whittaker
    %**********************************************************************
    %**********************************************************************
    % Performing the 2D gaussian fit
    %**********************************************************************
    %tol=0.000001;% tolerance of the fitting Tol=0.01  
    %tol=1e-5;% tolerance of the fitting Tol=0.01
    %[cx,cy,sx,sy,PeakOD] = fitgauss2d(img_tmp,tol);
    
    %**********************************************************************
    % Performing the Whittaker fit
    %**********************************************************************
    tol=1e-5;
    [cx,cy] = fitwhittaker2d(img_tmp,tol);
    
    %**********************************************************************
    % Performing the Gaussian fit
    %**********************************************************************
    %tol=1e-4;
    %[cx,cy] = fitgauss1Db(img_tmp,tol);
    
    %**********************************************************************
    displace_x=(cx-(lim+1)+(coarse_peak_x-zero_displ_x))
    displace_y=((cy-(lim+1))+(coarse_peak_y-zero_displ_y))
      
    
    %displace_x=coarse_peak_x-zero_displ_x;
    %displace_y=coarse_peak_y-zero_displ_y;
else
    displace_x=(coarse_peak_x-zero_displ_x);
    displace_y=(coarse_peak_y-zero_displ_y);
end

warning on;

return
    
