function [cx,cy,sx,sy,PeakOD] = fitgauss2d(m,tol);
% function to perform a 2D gaussian fit
%% m = image
%tol = fitting tolerance

options = optimset('Display','off','TolFun',tol,'LargeScale','off','MaxIter',5);
%options = optimset('Display','off','LargeScale','off');

[sizey sizex] = size(m);
[cx,cy,sx,sy] = centerofmass(m);
pOD = max(max(m));

mx = m(round(cy),:);
x1D = 1:sizex;
ip1D = [cx,sx,pOD];
fp1D = fminunc(@gaussian1d_function,ip1D,options,mx,x1D);

cx = fp1D(1);
sx = fp1D(2);
PeakOD = fp1D(3);

tmp=size(m);
if round(cx)<=0
    my = m(:,1)';
elseif round(cx)> tmp(2)
    my = m(:,tmp(2))';    
else
    my = m(:,round(cx))';
end

y1D = 1:sizey;
ip1D = [cy,sy,pOD];
fp1D = fminunc(@gaussian1d_function,ip1D,options,my,y1D);

cy = fp1D(1);
sy = fp1D(2);
PeakOD = fp1D(3);
[X,Y] = meshgrid(1:sizex,1:sizey);

initpar = [cx,cy,sx,sy,PeakOD];
fp = fminunc(@gaussian2D_function,initpar,options,m,X,Y);
cx = fp(2);
cy = fp(1);
sx = fp(4);
sy = fp(3);
PeakOD = fp(5);

%figure
%contour(m,10);
%hold on
%plot(cy,cx,'xk')



%**********************************************
% PURPOSE: find c of m of distribution
function [cx,cy,sx,sy] = centerofmass(m);

[sizey sizex] = size(m);
vx = sum(m);
vy = sum(m');

vx = vx.*(vx>0);
vy = vy.*(vy>0);

x = [1:sizex];
y = [1:sizey];

cx = sum(vx.*x)/sum(vx);
cy = sum(vy.*y)/sum(vy);

sx = sqrt(sum(vx.*(abs(x-cx).^2))/sum(vx));
sy = sqrt(sum(vy.*(abs(y-cy).^2))/sum(vy));


