function [img1,img2]=graynorm(image1,image2,inter_win,threshold)
% function to normalize the gray values of the images
% before the calculation of the cross correlation
% the function uses a no-linear filter suggested in the work:
% S. T. Wereley, L. Gui (2001).Software, Algorithm, and Procedures for Evaluating PIV Images in 
% the PIV Challenge 2001 Packages 
%
disp('Gray scale normalization');
image1=double(image1);
image2=double(image2);

image1=image1-threshold*max(max(image1)); % 0.85 std remove background
image2=image2-threshold*max(max(image2)); % 0.85 std the second exposure always have brighter background

[tmpx1,tmpy1]=find(image1<0);
[tmpx2,tmpy2]=find(image2<0);

for iin=1:length(tmpx1)
    image1(tmpx1(iin),tmpy1(iin))=0;
end
for iin=1:length(tmpx2)
    image2(tmpx2(iin),tmpy2(iin))=0;
end


nimg=size(image1);
% normalize locally for each interrogation window
n_stp_x=floor(nimg(1)/inter_win); % number of windows in x direction
stp_x=floor(inter_win);
n_stp_y=floor(nimg(2)/inter_win); % number of windows in y direction
stp_y=floor(inter_win);

max_global=round(0.9*2^nextpow2(max(max(image1)))); % global maximum gray level in the images
min_global=0; % minimum global of the images
img1=image1;
img2=image2;
for iin=1:n_stp_x
    for jjn=1:n_stp_y
        max_local1=max(max(image1((iin-1)*stp_x+1:iin*stp_x,(jjn-1)*stp_y+1:jjn*stp_y) )); % maximum gray lavel of the frame 1
        max_local2=max(max(image2((iin-1)*stp_x+1:iin*stp_x,(jjn-1)*stp_y+1:jjn*stp_y)  )); % maximum gray lavel of the frame 2
        min_local1=min(min(image1((iin-1)*stp_x+1:iin*stp_x,(jjn-1)*stp_y+1:jjn*stp_y)  )); % minimum gray lavel of the frame 1
        min_local2=min(min(image2((iin-1)*stp_x+1:iin*stp_x,(jjn-1)*stp_y+1:jjn*stp_y)  )); % minimum gray lavel of the frame 2
        if max_local1-min_local1==0
            max_local1=max_global;
        end
        if max_local2-min_local2==0
            max_local2=max_global;
        end

        img1((iin-1)*stp_x+1:iin*stp_x,(jjn-1)*stp_y+1:jjn*stp_y)=(max_global-min_global)*(image1((iin-1)*stp_x+1:iin*stp_x,(jjn-1)*stp_y+1:jjn*stp_y)-min_local1)/(max_local1-min_local1)+min_global;
        img2((iin-1)*stp_x+1:iin*stp_x,(jjn-1)*stp_y+1:jjn*stp_y)=(max_global-min_global)*(image2((iin-1)*stp_x+1:iin*stp_x,(jjn-1)*stp_y+1:jjn*stp_y)-min_local2)/(max_local2-min_local2)+min_global;
    end
end

return
