function [displ_x_new,displ_y_new,count_o]=norm_med(displ_x,displ_y,e_thres)
%****************************************************************************
% Function to remove outliers using the normalized median test - 
% Ouliers are replaced by Nan
%******************************************************************************
% Parameters
% displ_x   = displacement in x direction
% displ_y   = displacement in y direction
% e_thres   = threshold for the outlier detection, typical value is 2.1
% e_0       = remaining fluctuations from correlation analysis. In practice varies from
%               0.1 to 0.2px (see pag 185 particle image velocimetry Raffel et al 2007)
%****************************************************************************
e_0=0.2;

if exist('e_thres')==0
    %e_thres=25; % threshold for the amplitude
    %e_thres_ang=0.5*pi; %threshold for the angle
    e_thres=2.2;% threshold for the amplitude
%    e_thres_ang=10*pi; %threshold for the angle
end

displ_x_new=displ_x;
displ_y_new=displ_y;
%vel_pix=sqrt(displ_x.^2+displ_y.^2); % velocity in pixel
%ang=atan2(displ_y,displ_x);% angle of the vector

n_times_x=length(displ_x(:,1)); % number vertical points in the vector field
n_times_y=length(displ_x(1,:)); % number horizontal points in the vector field

 %check is done in a 3X3 points window
 count_o=0;

 % first verificarions are done along the border lines and columns
 % (it is used the mean criteria due to the restricted amount of points)
 for in=1:n_times_x-1:n_times_x
     if in==1
         ctrl=1;
     else
         ctrl=-1;
     end
    for jn=2:n_times_y-1
        clear tmpxx tmpyy tmpxd tmpyd
        tmpxx=find(~isnan(reshape(displ_x(in:ctrl:in+ctrl,jn-1:jn+1),1,[])));
        tmpxd=reshape(displ_x(in:ctrl:in+ctrl,jn-1:jn+1),1,[]);
        udiff=sum(abs(tmpxd(tmpxx)-displ_x(in,jn))> mean(abs(tmpxd(tmpxx)))); % alternative criteria based on vector difference test
        %um=mean(tmpxd(tmpxx)); %mean of the velocity U, use the mean criteria for the borders
        %r_um=mean(abs(tmpxd(tmpxx)-um)); %residuals of U
        
        tmpyy=find(~isnan(reshape(displ_y(in:ctrl:in+ctrl,jn-1:jn+1),1,[])));
        tmpyd=reshape(displ_y(in:ctrl:in+ctrl,jn-1:jn+1),1,[]);
        vdiff=sum(abs(tmpyd(tmpyy)-displ_y(in,jn))> mean(abs(tmpyd(tmpyy)))); % alternative criteria based on vector difference test
        
        %vm=mean(tmpyd(tmpyy)); %mean of the velocity V
        %r_vm=mean(abs(tmpyd(tmpyy)-vm)); %residuals of V
        

        diff_sigx=sum(sign(tmpxd(tmpxx))~=sign(displ_x(in,jn)));
        diff_sigy=sum(sign(tmpyd(tmpyy))~=sign(displ_y(in,jn)));
        
        if udiff >= round((e_thres/4)*length(tmpxd)) || vdiff >= round((e_thres/4)*length(tmpyd)) || diff_sigx >= round((e_thres/4)*length(tmpxd)) || diff_sigy >= round((e_thres/4)*length(tmpyd))
        %if abs(um-displ_x(in,jn))/(r_um+e_0)> e_thres | abs(vm-displ_y(in,jn))/(r_vm+e_0)>e_thres 
            
            displ_x_new(in,jn)=nan;
            displ_y_new(in,jn)=nan;
            count_o=count_o+1;
        end
    end
end

for jn=1:n_times_y-1:n_times_y
    if jn==1
         ctrl=1;
     else
         ctrl=-1;
     end
    for in=2:n_times_x-1
        clear tmpxx tmpyy tmpxd tmpyd
        tmpxx=find(~isnan(reshape(displ_x(in-1:in+1,jn:ctrl:jn+ctrl),1,[])));
        tmpxd=reshape(displ_x(in-1:in+1,jn:ctrl:jn+ctrl),1,[]);
        udiff=sum(abs(tmpxd(tmpxx)-displ_x(in,jn))> mean(abs(tmpxd(tmpxx)))); % alternative criteria based on vector difference test
        
        %um=mean(tmpxd(tmpxx)); %mean of the velocity U
        %r_um=mean(abs(tmpxd(tmpxx)-um)); %residuals of U
        
        tmpyy=find(~isnan(reshape(displ_y(in-1:in+1,jn:ctrl:jn+ctrl),1,[])));
        tmpyd=reshape(displ_y(in-1:in+1,jn:ctrl:jn+ctrl),1,[]);
        vdiff=sum(abs(tmpyd(tmpyy)-displ_y(in,jn))> mean(abs(tmpyd(tmpyy)))); % alternative criteria based on vector difference test
        
        %vm=mean(tmpyd(tmpyy)); %mean of the velocity V
        %r_vm=mean(abs(tmpyd(tmpyy)-vm)); %residuals of V
        
        %a_m=median(~isnan(reshape(ang(in-1:in+1,jn:ctrl:jn+ctrl),1,[]))); % median of the angle
        %res_a_m=median(~isnan(reshape(ang(in-1:in+1,jn:ctrl:jn+ctrl),1,[]))-a_m); %residuals of the angle
        diff_sigx=sum(sign(tmpxd)~=sign(displ_x(in,jn)));
        diff_sigy=sum(sign(tmpyd)~=sign(displ_y(in,jn)));
        
        if udiff >= round((e_thres/4)*length(tmpxd)) || vdiff >= round((e_thres/4)*length(tmpyd)) || diff_sigx >= round((e_thres/4)*length(tmpxd)) || diff_sigy >= round((e_thres/4)*length(tmpyd))
        %if abs(um-displ_x(in,jn))/(r_um+e_0)> e_thres | abs(vm-displ_y(in,jn))/(r_vm+e_0)>e_thres 
            displ_x_new(in,jn)=nan;
            displ_y_new(in,jn)=nan;
            count_o=count_o+1;
        end
    end
end


% then the search is done for the rest of the vector matrix
for in=2:n_times_x-1
    for jn=2:n_times_y-1
        clear tmpxx tmpyy tmpxd tmpyd
        tmpxx=find(reshape(~isnan(displ_x(in-1:in+1,jn-1:jn+1)),1,[]));
        tmpxd=reshape(displ_x(in-1:in+1,jn-1:jn+1),1,[]);
        um=median(tmpxd(tmpxx)); %median of the velocity U
        r_um=median(abs(tmpxd(tmpxx)-um)); %residuals of U
        tmpyy=find(reshape(~isnan(displ_y(in-1:in+1,jn-1:jn+1)),1,[]));
        tmpyd=reshape(displ_y(in-1:in+1,jn-1:jn+1),1,[]);
        vm=median(tmpyd(tmpyy)); %median of the velocity V
        r_vm=median(abs(tmpyd(tmpyy)-vm)); %residuals of V
        %a_m=median(~isnan(reshape(ang(in,jn-1:jn+1),1,[]))); % median of the angle
        %res_a_m=median(~isnan(reshape(ang(in,jn-1:jn+1),1,[]))-a_m); %residuals of the angle
        if abs(um-displ_x(in,jn))/(r_um+e_0)> e_thres || abs(vm-displ_y(in,jn))/(r_vm+e_0)>e_thres  %| abs((a_m-ang(in,jn))/(res_a_m+1))> e_thres_ang
            displ_x_new(in,jn)=nan;
            displ_y_new(in,jn)=nan;
            count_o=count_o+1;
        end
    end
end
disp(['n of outliers=' num2str(count_o)]);

return