function [u,v,x,y,displ_x,displ_y,frame1,frame2]= piv(frame1,frame2,frame_rate,length_x,length_y,inter_win,option_win,inter_win_end,over_lap)
% Program to calculate the velocity vectors from a pair of
% images
%************ Input parameters**********
%_______________Data_________________
%Frame 1; % first image of the pair
%Frame2; % second image of the pair
%frame_rate; % 1/time elapsed between the two shots
%length_x; % physical length of the domain
%inter_win; %length of the interrogation window (results in 2^n X 2^n dimensions)
%overlap; % degree of overlap in search windows


%______________Options________________
% add in future: multi-pass, Hart, image deformation...
warning off
if exist('option_win')==0 
    option_win='simple_pass'
end
if exist('over_lap')==0
    over_lap=0.5;
end

%_____________________________________

% 1st step - Image Binarization

%normalization of the grayscales of the image (Commented because this is
%already set in the main program)
%[frame1,frame2]=graynorm(frame1,frame2,inter_win);

% 2nd calibration of the image (afterwards can read a calibration file)
size_frame=size(frame1);
n_pix_x=size_frame(1); % pixels in x direction
n_pix_y=size_frame(2); % pixels in y direction
ratiox_pix_m=n_pix_x/length_x;% ratio in pixel per meter
ratioy_pix_m=n_pix_y/length_y;% ratio in pixel per meter

% 3rd interrogation windows
switch lower(option_win)
    
case {'simple_pass'}
    [displ_x,displ_y,x,y]=simple_pass(frame1,frame2,inter_win,over_lap);
    [displ_x,displ_y]=norm_med(displ_x,displ_y); % remove outliers using the normalized median
    %displ_x = naninterp(displ_x); % interpolate over the Nan's
    %displ_y = naninterp(displ_y);
case {'hart_single'}
    [displ_x,displ_y,x,y]=hart_single2(frame1,frame2,inter_win,over_lap);
%    [displ_x,displ_y]=norm_med(displ_x,displ_y); % remove outliers using the normalized median
%    displ_x = naninterp(displ_x); % interpolate over the Nan's
%    displ_y = naninterp(displ_y);
case {'multi_pass'}
    [displ_x,displ_y,x,y]=multi_pass2(frame1,frame2,inter_win,inter_win_end,over_lap);
    %outliers are already removed
    [displ_x,displ_y]=norm_med(displ_x,displ_y); % remove outliers using the normalized median
%    displ_x = naninterp(displ_x); % interpolate over the Nan's
%    displ_y = naninterp(displ_y);
case {'npass'}
    [displ_x,displ_y,x,y]=npass(frame1,frame2,inter_win,over_lap);
end


% 4rd calculation of the velocities
%u=(displ_x/ratiox_pix_m)*frame_rate; %calculation of velocity, im meter/sec
%v=(displ_y/ratioy_pix_m)*frame_rate; %calculation of velocity, im meter/sec
u=displ_x; % show only the displacements instead of velocities 
v=displ_y; % show only the displacements instead of velocities 
warning on
return