function [displ_x,displ_y,win_pos_x,win_pos_y]=simple_pass(frameA,frameB,inter_win,overlap)
% function to calculate the displacement based on single pass window
% procedure

% Parameters
% frameA    = 1st image from the pair
% frameB    = 2nd image from the pair
% inter_win = interrogation window (power of 2)
% displ_x   = displacement in x direction (in pixel)
% displ_y   = displacement in y direction (in pixel)
% overlap   = overlap of the interrogation windows
% win_pos_x = position of the windows in x (in pixel)
% win_pos_y = position of the windows in y (in pixel)

if isempty(overlap)==1
    overlap=0; %overlap of 0%
end

n_point=size(frameA); 

n_steps_x=floor(n_point(1)/inter_win/(1-overlap))-1; % number of windows in x direction
step_x=floor(inter_win*(1-overlap));
n_steps_y=floor(n_point(2)/inter_win/(1-overlap))-1; % number of windows in y direction
step_y=floor(inter_win*(1-overlap));
disp(['Nsteps_x=' num2str(n_steps_x) ',Step_x=' num2str(step_x) ',Nsteps_y=' num2str(n_steps_y) ',Steps_y=' num2str(step_y)]);
for i=1:n_steps_x
    for j=1:n_steps_y
        % interrogation window
        imag1_tmp=frameA((i-1)*step_x+1:(i-1)*step_x+inter_win,(j-1)*step_y+1:(j-1)*step_y+inter_win);
        imag2_tmp=frameB((i-1)*step_x+1:(i-1)*step_x+inter_win,(j-1)*step_y+1:(j-1)*step_y+inter_win);
        % cross correlation
        c_corr= image_cc(imag1_tmp,imag2_tmp);
        %c_corr= image_cc_sum(imag1_tmp,imag2_tmp);
        % displacement with sub pixel accuracy
        [displ_x(i,j),displ_y(i,j)]= find_disp(c_corr);
        win_pos_x(i,j)=median((i-1)*step_x+1:(i-1)*step_x+inter_win);
        win_pos_y(i,j)=median((j-1)*step_y+1:(j-1)*step_y+inter_win);       
    end
end
%[displ_x,displ_y]=norm_med(displ_x,displ_y); % remove outliers using the normalized median
%displ_x = naninterp(displ_x); % interpolate over the Nan's
%displ_y = naninterp(displ_y);

return